@@ -29,7 +29,7 @@ def test_update():
     for o in s.query(T):
         assert o.i == 3
     
-    s.query(T).filter(T.f.i==3).set(T.f.i, 4).execute()
+    s.query(T).filter(T.i==3).set(T.i, 4).execute()
     
     for o in s.query(T):
         assert o.i == 4
@@ -41,13 +41,13 @@ def test_field_filter():
     # Simple Object
     obj = T(i=3)
     s.insert(obj)
-    for t in s.query(T).fields(T.f.i):
+    for t in s.query(T).fields(T.i):
         break
     assert t.i == 3
     # Nested Object
     obj2 = T2(t=obj)
     s.insert(obj2)
-    for t2 in s.query(T2).fields(T2.f.t.i):
+    for t2 in s.query(T2).fields(T2.t.i):
         break
     assert t2.t.i == 3
 
@@ -76,13 +76,13 @@ def test_hint():
     s.clear_collection(T)
     s.insert(T(i=3))
     s.insert(T(i=4))
-    for item in s.query(T).hint_asc(T.f.i):
+    for item in s.query(T).hint_asc(T.i):
         pass
 
 @raises(BadQueryException)
 def test_hint_validation():
     s = get_session()
-    s.query(T).hint_asc(T.f.i).hint_desc(T.f.i)
+    s.query(T).hint_asc(T.i).hint_desc(T.i)
 
 @raises(BadResultException) # too many values to unpack
 def test_one_fail():
@@ -110,15 +110,15 @@ def test_first():
     s.clear_collection(T)
     s.insert(T(i=3))
     s.insert(T(i=4))
-    assert s.query(T).descending(T.f.i).first().i == 4
-    assert s.query(T).ascending(T.f.i).first().i == 3
+    assert s.query(T).descending(T.i).first().i == 4
+    assert s.query(T).ascending(T.i).first().i == 3
 
 def test_first_empty():
     s = get_session()
     s.clear_collection(T)
     s.insert(T(i=3))
     s.insert(T(i=4))
-    assert s.query(T).filter(T.f.i > 5).first() == None
+    assert s.query(T).filter(T.i > 5).first() == None
 
 def test_all():
     s = get_session()
@@ -135,7 +135,7 @@ def test_distinct():
     s.insert(T(i=3, j=4))
     s.insert(T(i=3, j=5))
     s.insert(T(i=3, j=6))
-    for count, item in enumerate(s.query(T).distinct(T.f.i)):
+    for count, item in enumerate(s.query(T).distinct(T.i)):
         pass
     assert count == 0, count
 
@@ -153,7 +153,7 @@ def test_explain():
     s.clear_collection(T)
     s.insert(T(i=3))
     s.insert(T(i=4))
-    assert 'allPlans' in s.query(T).filter(T.f.i > 5).explain()
+    assert 'allPlans' in s.query(T).filter(T.i > 5).explain()
 
 
 def test_clone():
@@ -174,7 +174,7 @@ def test_field_filter_non_retrieved_field():
     s.clear_collection(T)
     obj = T(i=3, j=2)
     s.insert(obj)
-    for t in s.query(T).fields(T.f.i):
+    for t in s.query(T).fields(T.i):
         break
     assert t.j == 2
 
@@ -185,7 +185,7 @@ def test_field_filter_non_retrieved_subdocument_field():
     obj = T(i=3, j=2)
     obj2 = T2(t=obj)
     s.insert(obj2)
-    for t2 in s.query(T2).fields(T2.f.t.i):
+    for t2 in s.query(T2).fields(T2.t.i):
         break
     assert t2.t.j == 2
 
@@ -193,48 +193,48 @@ def test_field_filter_non_retrieved_subdocument_field():
 def repeated_field_query_test():
     s = get_session()
     s.clear_collection(T)
-    s.query(T).filter(T.f.i==3).filter(T.f.i==3)
+    s.query(T).filter(T.i==3).filter(T.i==3)
 
 @raises(Exception)
 def repeated_field_query_test2():
     s = get_session()
     s.clear_collection(T)
-    s.query(T).filter(T.f.i==3, T.f.i==3)
+    s.query(T).filter(T.i==3, T.i==3)
 
 def nested_field_query_test():
     s = get_session()
     s.clear_collection(T, T2)
-    s.query(T2).filter(T2.f.t.i==3, T2.f.t.j==2)
+    s.query(T2).filter(T2.t.i==3, T2.t.j==2)
 
 @known_failure
 @raises(Exception)
 def repeated_field_update_test():
     s = get_session()
     s.clear_collection(T)
-    s.query(T).filter(T.f.i==3).set(T.f.i, 4).set(T.f.i, 5)
+    s.query(T).filter(T.i==3).set(T.i, 4).set(T.i, 5)
 
 def test_comparators():
     # once filters have more sanity checking, this test will need to be broken up
     s = get_session()
-    query_obj = s.query(T).filter(T.f.i < 2, 
-        T.f.i > 3,
-        T.f.i != 4,
-        T.f.i <= 5,
-        T.f.i >= 6).query
+    query_obj = s.query(T).filter(T.i < 2, 
+        T.i > 3,
+        T.i != 4,
+        T.i <= 5,
+        T.i >= 6).query
     
     assert query_obj == {'i': {'$ne': 4, '$gte': 6, '$lte': 5, '$gt': 3, '$lt': 2}}
     
-    s.query(T).filter(T.f.i == 1).query == { 'i' : 1}
+    s.query(T).filter(T.i == 1).query == { 'i' : 1}
 
 @raises(BadQueryException)
 def invalid_combination_test():
     s = get_session()
-    s.query(T).filter(T.f.i < 2, T.f.i == 4)
+    s.query(T).filter(T.i < 2, T.i == 4)
 
 def test_sort():
     from pymongo import ASCENDING, DESCENDING
     s = get_session()
-    sorted_query = s.query(T).ascending(T.f.i).descending(T.f.j)
+    sorted_query = s.query(T).ascending(T.i).descending(T.j)
     assert sorted_query.sort == [('i', ASCENDING),('j', DESCENDING)], sorted_query.sort
     for obj in sorted_query:
         pass
@@ -242,7 +242,7 @@ def test_sort():
 @raises(BadQueryException)
 def test_sort_by_same_key():
     s = get_session()
-    sorted_query = s.query(T).ascending(T.f.i).descending(T.f.i)
+    sorted_query = s.query(T).ascending(T.i).descending(T.i)
 
 
 #
@@ -259,7 +259,7 @@ def qr_test_getitem():
     s.clear_collection(T)
     s.insert(T(i=3))
     s.insert(T(i=4))
-    assert s.query(T).descending(T.f.i)[0].i == 4
+    assert s.query(T).descending(T.i)[0].i == 4
 
 def qr_test_rewind():
     s = get_session()
